Location

Struct Location 

pub struct Location<'c> { /* private fields */ }
A location

Implementations

Source

impl<'c> Location<'c>

pub fn new( context: &'c Context, filename: &str, line: usize, column: usize, ) -> Self

Creates a location with a filename and line and column numbers.

pub fn fused( context: &'c Context, locations: &[Self], attribute: Attribute<'_>, ) -> Self

Creates a fused location.

pub fn name(context: &'c Context, name: &str, child: Location<'_>) -> Self

Creates a name location.

pub fn call_site(callee: Location<'_>, caller: Location<'_>) -> Self

Creates a call site location.

pub fn file_line_col_range( context: &'c Context, filename: &str, start_line: usize, start_col: usize, end_line: usize, end_col: usize, ) -> Self

Creates a file/line/column range location.

pub fn unknown(context: &'c Context) -> Self

Creates an unknown location.

pub fn context(&self) -> ContextRef<'c>

Returns a context.

pub fn is_call_site(&self) -> bool

Returns true if this location is a call site location.

pub fn is_file_line_col_range(&self) -> bool

Returns true if this location is a file/line/column range location.

pub fn is_fused(&self) -> bool

Returns true if this location is a fused location.

pub fn is_name(&self) -> bool

Returns true if this location is a name location.

pub fn call_site_callee(&self) -> Self

Returns the callee of a call site location.

pub fn call_site_caller(&self) -> Self

Returns the caller of a call site location.

pub fn file_line_col_range_filename(&self) -> Identifier<'c>

Returns the filename of a file/line/column range location.

pub fn file_line_col_range_start_line(&self) -> usize

Returns the start line of a file/line/column range location.

pub fn file_line_col_range_start_column(&self) -> usize

Returns the start column of a file/line/column range location.

pub fn file_line_col_range_end_line(&self) -> usize

Returns the end line of a file/line/column range location.

pub fn file_line_col_range_end_column(&self) -> usize

Returns the end column of a file/line/column range location.

pub fn fused_num_locations(&self) -> usize

Returns the number of locations in a fused location.

pub fn fused_location(&self, index: usize) -> Self

Returns the location at index in a fused location.

pub fn fused_metadata(&self) -> Attribute<'c>

Returns the metadata attribute of a fused location.

pub fn name_value(&self) -> Identifier<'c>

Returns the name identifier of a name location.

pub fn name_child_location(&self) -> Self

Returns the child location of a name location.

pub fn to_attribute(&self) -> Attribute<'c>

Converts this location to an attribute.

pub fn from_attribute(attribute: Attribute<'c>) -> Self

Creates a location from an attribute.

pub unsafe fn from_raw(raw: MlirLocation) -> Self

Creates a location from a raw object.

Safety

A raw object must be valid.

pub const fn to_raw(self) -> MlirLocation

Converts a location into a raw object.